#!/usr/bin/env bash

shopt -s dotglob
[ "${DEBUG:-}" == 'true' ] && set -x

set_default ()
{
    server_port='2456'
    server_hostname='Valheim created by GameAP'
    server_rcon_password='secretpass'
    server_word='Dedicated'
}

parse_options ()
{
    for i in "$@"
    do
        case $i in
            -h|--help)
                show_logo
                show_help
                exit 0
            ;;
            --port=*)
                server_port="${i#*=}"
                shift
            ;;
            --rcon-password=*)
                server_rcon_password="${i#*=}"
                shift
            ;;
            --hostname=*)
                server_hostname="${i#*=}"
                shift
            ;;
            --word=*)
                server_word="${i#*=}"
                shift
            ;;
        esac
    done
}

show_help ()
{
    echo
    echo 'Usage:	./run.sh COMMAND [OPTIONS]'
    echo
    echo 'Options:'
    echo '      --port=                 Server port'
    echo '      --rcon-password=        Server rcon password'
    echo '      --hostname=             Server hostname'
    echo '      --word=                 Server word'
    echo
    echo 'Examples:'
    echo '      ./run.sh --hostname="My Super Server" --port=2456 --rcon-password=secretpassword --word=Dedicated'
}

show_logo ()
{
    echo
    echo '
                  ###           ####
               #######################
               #######################
              #######````````````#######
            ######   ############   ######
          #####  ####             ##  ########
      ########  ###               ####  ########
     ######## ###                 ###### ########
      ###### ####     ################### ######
       ####  ####     ################### #####
       #### #####     ###           #####  ####
       #### #####     ###           #####  ####
       ####  ####     #########     ##### #####
      ###### ####     #########     ##### ######
     ######## ###       ######      #### ########
      ########  ##                 ###  ########
       ########   ###            ###   #####
            #####    ############   ######
              #######````````````#######
                #######################
                #######################
                 #####          ####'
    echo
    echo '             GameAP Valheim Server Runner'
    echo
    echo '----------------------------------------------------'
    echo
}

run ()
{
    export LD_LIBRARY_PATH=./linux64:$LD_LIBRARY_PATH
    export SteamAppId=892970

    ./valheim_server.x86_64 -name "${server_hostname:-Valheim}" -port ${server_port:-2456} -world "${server_word:-Dedicated}" -password "${server_rcon_password:-secretpassword}" -crossplay
}

main ()
{
    show_logo
    run
}

set_default
parse_options "$@"
main
